==> allensdk-2.13.3-py3-none-any.whl: allensdk/brain_observatory/behavior/data_files/rigid_motion_transform_file.py <==
import json
from typing import Dict, Union
from pathlib import Path

from cachetools import cached, LRUCache
from cachetools.keys import hashkey

import pandas as pd

from allensdk.internal.api import PostgresQueryMixin
from allensdk.brain_observatory.behavior.data_files import DataFile
from allensdk.internal.core.lims_utilities import safe_system_path


def from_json_cache_key(cls, dict_repr: dict):
    return hashkey(json.dumps(dict_repr))


def from_lims_cache_key(cls, db, ophys_experiment_id: int):
    return hashkey(ophys_experiment_id)


class RigidMotionTransformFile(DataFile):
    """A DataFile which contains methods for accessing and loading
    rigid motion transform output.
    """

    def __init__(self, filepath: Union[str, Path]):
        super().__init__(filepath=filepath)

    @classmethod
    @cached(cache=LRUCache(maxsize=10), key=from_json_cache_key)
    def from_json(cls, dict_repr: dict) -> "RigidMotionTransformFile":
        filepath = dict_repr["rigid_motion_transform_file"]
        return cls(filepath=filepath)

    def to_json(self) -> Dict[str, str]:
        return {"rigid_motion_transform_file": str(self.filepath)}

    @classmethod
    @cached(cache=LRUCache(maxsize=10), key=from_lims_cache_key)
    def from_lims(
        cls, db: PostgresQueryMixin,
        ophys_experiment_id: Union[int, str]
    ) -> "RigidMotionTransformFile":
        query = """
                SELECT wkf.storage_directory || wkf.filename AS transform_file
                FROM ophys_experiments oe
                JOIN well_known_files wkf ON wkf.attachable_id = oe.id
                JOIN well_known_file_types wkft
                ON wkft.id = wkf.well_known_file_type_id
                WHERE wkf.attachable_type = 'OphysExperiment'
                AND wkft.name = 'OphysMotionXyOffsetData'
                AND oe.id = {};
                """.format(ophys_experiment_id)
        filepath = safe_system_path(db.fetchone(query, strict=True))
        return cls(filepath=filepath)

    @staticmethod
    def load_data(filepath: Union[str, Path]) -> pd.DataFrame:
        motion_correction = pd.read_csv(filepath)
        return motion_correction[['x', 'y']]

==> allensdk-2.14.0-py3-none-any.whl: allensdk/brain_observatory/behavior/data_files/rigid_motion_transform_file.py <==
import json
from typing import Dict, Union
from pathlib import Path

from cachetools import cached, LRUCache
from cachetools.keys import hashkey

import pandas as pd

from allensdk.internal.api import PostgresQueryMixin
from allensdk.internal.core.lims_utilities import safe_system_path
from allensdk.internal.core import DataFile


def from_json_cache_key(cls, dict_repr: dict):
    return hashkey(json.dumps(dict_repr))


def from_lims_cache_key(cls, db, ophys_experiment_id: int):
    return hashkey(ophys_experiment_id)


class RigidMotionTransformFile(DataFile):
    """A DataFile which contains methods for accessing and loading
    rigid motion transform output.
    """

    def __init__(self, filepath: Union[str, Path]):
        super().__init__(filepath=filepath)

    @classmethod
    @cached(cache=LRUCache(maxsize=10), key=from_json_cache_key)
    def from_json(cls, dict_repr: dict) -> "RigidMotionTransformFile":
        filepath = dict_repr["rigid_motion_transform_file"]
        return cls(filepath=filepath)

    def to_json(self) -> Dict[str, str]:
        return {"rigid_motion_transform_file": str(self.filepath)}

    @classmethod
    @cached(cache=LRUCache(maxsize=10), key=from_lims_cache_key)
    def from_lims(
        cls, db: PostgresQueryMixin,
        ophys_experiment_id: Union[int, str]
    ) -> "RigidMotionTransformFile":
        query = """
                SELECT wkf.storage_directory || wkf.filename AS transform_file
                FROM ophys_experiments oe
                JOIN well_known_files wkf ON wkf.attachable_id = oe.id
                JOIN well_known_file_types wkft
                ON wkft.id = wkf.well_known_file_type_id
                WHERE wkf.attachable_type = 'OphysExperiment'
                AND wkft.name = 'OphysMotionXyOffsetData'
                AND oe.id = {};
                """.format(ophys_experiment_id)
        filepath = safe_system_path(db.fetchone(query, strict=True))
        return cls(filepath=filepath)

    @staticmethod
    def load_data(filepath: Union[str, Path]) -> pd.DataFrame:
        motion_correction = pd.read_csv(filepath)
        return motion_correction[['x', 'y']]
